Finish renaming track object to track element
authorThibault Saunier <thibault.saunier@collabora.com>
Fri, 8 Feb 2013 19:39:18 +0000 (16:39 -0300)
committerThibault Saunier <thibault.saunier@collabora.com>
Fri, 15 Feb 2013 18:23:15 +0000 (15:23 -0300)
19 files changed:
ges/ges-audio-test-source.c
ges/ges-clip.c
ges/ges-clip.h
ges/ges-custom-source-clip.h
ges/ges-image-source.c
ges/ges-pitivi-formatter.c
ges/ges-test-clip.c
ges/ges-text-overlay.c
ges/ges-timeline-layer.c
ges/ges-timeline.c
ges/ges-title-source.c
ges/ges-track-element.c
ges/ges-track.c
ges/ges-uri-clip.c
ges/ges.c
tests/check/ges/basic.c
tests/check/ges/transition.c
tests/check/ges/uriclip.c
tests/examples/ges-ui.c

index 9559c15..3f6ebcd 100644 (file)
@@ -116,7 +116,7 @@ ges_audio_test_source_create_element (GESTrackElement * trksrc)
  * @self: a #GESAudioTestSource
  * @freq: The frequency you want to apply on @self
  *
- * Lets you set the frequency applied on the track object
+ * Lets you set the frequency applied on the track element
  */
 void
 ges_audio_test_source_set_freq (GESAudioTestSource * self, gdouble freq)
index e4b2d75..8218ded 100644 (file)
@@ -120,7 +120,7 @@ struct _GESClipPrivate
 
   /*< private > */
 
-  /* Set to TRUE when the clip is doing updates of track object
+  /* Set to TRUE when the clip is doing updates of track element
    * properties so we don't end up in infinite property update loops
    */
   gboolean ignore_notifies;
@@ -266,30 +266,30 @@ ges_clip_class_init (GESClipClass * klass)
       G_TYPE_NONE, 1, GES_TYPE_BASE_EFFECT);
 
   /**
-   * GESClip::track-object-added:
+   * GESClip::track-element-added:
    * @object: the #GESClip
    * @trackelement: the #GESTrackElement that was added.
    *
-   * Will be emitted after a track object was added to the object.
+   * Will be emitted after a track element was added to the object.
    *
    * Since: 0.10.2
    */
   ges_clip_signals[TRACK_ELEMENT_ADDED] =
-      g_signal_new ("track-object-added", G_TYPE_FROM_CLASS (klass),
+      g_signal_new ("track-element-added", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_FIRST, 0, NULL, NULL, g_cclosure_marshal_generic,
       G_TYPE_NONE, 1, GES_TYPE_TRACK_ELEMENT);
 
   /**
-   * GESClip::track-object-removed:
+   * GESClip::track-element-removed:
    * @object: the #GESClip
    * @trackelement: the #GESTrackElement that was removed.
    *
-   * Will be emitted after a track object was removed from @object.
+   * Will be emitted after a track element was removed from @object.
    *
    * Since: 0.10.2
    */
   ges_clip_signals[TRACK_ELEMENT_REMOVED] =
-      g_signal_new ("track-object-removed", G_TYPE_FROM_CLASS (klass),
+      g_signal_new ("track-element-removed", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_FIRST, 0, NULL, NULL, g_cclosure_marshal_generic,
       G_TYPE_NONE, 1, GES_TYPE_TRACK_ELEMENT);
 
@@ -344,7 +344,7 @@ ges_clip_create_track_element (GESClip * object, GESTrackType type)
 
   g_return_val_if_fail (GES_IS_CLIP (object), NULL);
 
-  GST_DEBUG_OBJECT (object, "Creating track object for %s",
+  GST_DEBUG_OBJECT (object, "Creating track element for %s",
       ges_track_type_name (type));
   if (!(type & object->priv->supportedformats)) {
     GST_DEBUG_OBJECT (object, "We don't support this track type %i", type);
@@ -418,7 +418,7 @@ ges_clip_create_track_elements_func (GESClip * object, GESTrackType type)
       ges_track_type_name (type));
   result = ges_clip_create_track_element (object, type);
   if (!result) {
-    GST_DEBUG ("Did not create track object");
+    GST_DEBUG ("Did not create track element");
     return NULL;
   }
 
@@ -430,7 +430,7 @@ ges_clip_create_track_elements_func (GESClip * object, GESTrackType type)
  * @object: a #GESClip
  * @trobj: the GESTrackElement
  *
- * Add a track object to the timeline object. Should only be called by
+ * Add a track element to the timeline object. Should only be called by
  * subclasses implementing the create_track_elements (plural) vmethod.
  *
  * Takes a reference on @trobj.
@@ -468,7 +468,7 @@ ges_clip_add_track_element (GESClip * object, GESTrackElement * trobj)
   mapping->object = trobj;
   priv->mappings = g_list_append (priv->mappings, mapping);
 
-  GST_DEBUG ("Adding TrackElement to the list of controlled track objects");
+  GST_DEBUG ("Adding TrackElement to the list of controlled track elements");
   /* We steal the initial reference */
 
   GST_DEBUG ("Setting properties on newly created TrackElement");
@@ -609,7 +609,7 @@ ges_clip_release_track_element (GESClip * object,
 
   ges_track_element_set_clip (trackelement, NULL);
 
-  GST_DEBUG ("Removing reference to track object %p", trackelement);
+  GST_DEBUG ("Removing reference to track element %p", trackelement);
 
   if (klass->track_element_released) {
     GST_DEBUG ("Calling track_element_released subclass method");
@@ -925,7 +925,7 @@ ges_clip_move_to_layer (GESClip * object, GESTimelineLayer * layer)
  * ges_clip_find_track_element:
  * @object: a #GESClip
  * @track: a #GESTrack or NULL
- * @type: a #GType indicating the type of track object you are looking
+ * @type: a #GType indicating the type of track element you are looking
  * for or %G_TYPE_NONE if you do not care about the track type.
  *
  * Finds the #GESTrackElement controlled by @object that is used in @track. You
@@ -1321,17 +1321,17 @@ ges_clip_split (GESClip * object, guint64 position)
     ges_track_element_set_locked (new_trackelement, FALSE);
     ges_track_element_set_locked (trackelement, FALSE);
 
-    /* Set 'new' track object timing propeties */
+    /* Set 'new' track element timing propeties */
     _set_start0 (GES_TIMELINE_ELEMENT (new_trackelement), position);
     _set_inpoint0 (GES_TIMELINE_ELEMENT (new_trackelement),
         inpoint + duration - (duration + start - position));
     _set_duration0 (GES_TIMELINE_ELEMENT (new_trackelement),
         duration + start - position);
 
-    /* Set 'old' track object duration */
+    /* Set 'old' track element duration */
     _set_duration0 (GES_TIMELINE_ELEMENT (trackelement), position - start);
 
-    /* And let track objects in the same locking state as before. */
+    /* And let track elements in the same locking state as before. */
     ges_track_element_set_locked (trackelement, locked);
     ges_track_element_set_locked (new_trackelement, locked);
   }
@@ -1604,7 +1604,7 @@ update_height (GESClip * object)
 }
 
 /*
- * PROPERTY NOTIFICATIONS FROM TRACK OBJECTS
+ * PROPERTY NOTIFICATIONS FROM TRACK ELEMENTS
  */
 
 static void
index fd6e4fc..7d91e7a 100644 (file)
@@ -40,12 +40,12 @@ typedef struct _GESClipPrivate GESClipPrivate;
 
 /**
  * GESFillTrackElementFunc:
- * @object: the #GESClip controlling the track object
+ * @object: the #GESClip controlling the track elements
  * @trobject: the #GESTrackElement
  * @gnlobj: the GNonLin object that needs to be filled.
  *
  * A function that will be called when the GNonLin object of a corresponding
- * track object needs to be filled.
+ * track element needs to be filled.
  *
  * The implementer of this function shall add the proper #GstElement to @gnlobj
  * using gst_bin_add().
@@ -61,7 +61,7 @@ typedef gboolean (*GESFillTrackElementFunc) (GESClip *object,
  * @object: a #GESClip
  * @type: a #GESTrackType
  *
- * Creates the 'primary' track object for this @object.
+ * Creates the 'primary' track element for this @object.
  *
  * Subclasses should implement this method if they only provide a
  * single #GESTrackElement per track.
@@ -87,7 +87,7 @@ typedef GESTrackElement *(*GESCreateTrackElementFunc) (GESClip * object,
  * @object: a #GESClip
  * @type: a #GESTrackType
  *
- * Create all track objects this object handles for this type of track.
+ * Create all track elements this object handles for this type of track.
  *
  * Subclasses should implement this method if they potentially need to
  * return more than one #GESTrackElement(s) for a given #GESTrack.
index 0a1fc29..10b99d3 100644 (file)
@@ -48,13 +48,13 @@ typedef struct _GESCustomSourceClipPrivate   GESCustomSourceClipPrivate;
 
 /**
  * GESFillTrackElementUserFunc:
- * @object: the #GESClip controlling the track object
+ * @object: the #GESClip controlling the track element
  * @trobject: the #GESTrackElement
  * @gnlobj: the GNonLin object that needs to be filled.
  * @user_data: the gpointer to optional user data
  *
  * A function that will be called when the GNonLin object of a corresponding
- * track object needs to be filled.
+ * track element needs to be filled.
  *
  * The implementer of this function shall add the proper #GstElement to @gnlobj
  * using gst_bin_add().
index 37828d6..85745fd 100644 (file)
@@ -24,7 +24,7 @@
  * image.
  * 
  * Outputs the video stream from a given file as a still frame. The frame
- * chosen will be determined by the in-point property on the track object. For
+ * chosen will be determined by the in-point property on the track element. For
  * image files, do not set the in-point property.
  */
 
index 871706b..428022a 100644 (file)
@@ -155,7 +155,7 @@ save_track_elements (xmlTextWriterPtr writer, GList * source_list,
   gchar *bin_desc;
   xmlTextWriterStartElement (writer, BAD_CAST "track-objects");
 
-  GST_DEBUG ("Saving track objects");
+  GST_DEBUG ("Saving track elements");
   for (tmp = source_list; tmp; tmp = tmp->next) {
     SrcMapping *srcmap;
     GESClip *object;
@@ -174,7 +174,7 @@ save_track_elements (xmlTextWriterPtr writer, GList * source_list,
       const gchar *active, *locked;
 
       if (!track) {
-        GST_WARNING ("Track object %p not in a track yet", trackelement);
+        GST_WARNING ("Track element %p not in a track yet", trackelement);
         continue;
       }
 
@@ -806,7 +806,7 @@ track_element_added_cb (GESClip * object,
         || (!g_strcmp0 (media_type, "pitivi.stream.AudioStream")
             && track->type == GES_TRACK_TYPE_AUDIO)) {
 
-      /* We unlock the track objects so we do not move the whole Clip */
+      /* We unlock the track element so we do not move the whole Clip */
       ges_track_element_set_locked (tmp->data, FALSE);
       set_properties (G_OBJECT (tmp->data), props_table);
 
@@ -831,7 +831,7 @@ track_element_added_cb (GESClip * object,
 
       if (GES_IS_EFFECT (tmp->data)
           && (type == track->type)) {
-        /* We lock the track objects so we do not move the whole Clip */
+        /* We lock the track elements so we do not move the whole Clip */
         ges_track_element_set_locked (tmp->data, FALSE);
         g_object_set (tmp->data, "start", start, "duration", duration, NULL);
         if (locked)
@@ -891,7 +891,7 @@ make_source (GESFormatter * self, GList * reflist, GHashTable * source_table)
 
     if (g_strcmp0 (fac_ref, (gchar *) "effect")) {
       /* FIXME this is a hack to get a ref to the formatter when receiving
-       * track-object-added */
+       * track-element-added */
       g_hash_table_insert (props_table, (gchar *) "current-formatter", self);
       if (a_avail && (!video)) {
         a_avail = FALSE;
@@ -922,7 +922,7 @@ make_source (GESFormatter * self, GList * reflist, GHashTable * source_table)
         set_properties (G_OBJECT (src), props_table);
         ges_timeline_layer_add_object (layer, GES_CLIP (src));
 
-        g_signal_connect (src, "track-object-added",
+        g_signal_connect (src, "track-element-added",
             G_CALLBACK (track_element_added_cb), props_table);
 
         priv->sources_to_load = g_list_prepend (priv->sources_to_load, src);
index d0876a9..e025c43 100644 (file)
@@ -121,7 +121,7 @@ ges_test_clip_class_init (GESTestClipClass * klass)
   /**
    * GESTestClip:vpattern:
    *
-   * Video pattern to display in video track objects.
+   * Video pattern to display in video track elements.
    */
   g_object_class_install_property (object_class, PROP_VPATTERN,
       g_param_spec_enum ("vpattern", "VPattern",
@@ -132,7 +132,7 @@ ges_test_clip_class_init (GESTestClipClass * klass)
   /**
    * GESTestClip:freq:
    *
-   * The frequency to generate for audio track objects.
+   * The frequency to generate for audio track elements.
    */
   g_object_class_install_property (object_class, PROP_FREQ,
       g_param_spec_double ("freq", "Audio Frequency",
@@ -142,7 +142,7 @@ ges_test_clip_class_init (GESTestClipClass * klass)
   /**
    * GESTestClip:volume:
    *
-   * The volume for the audio track objects.
+   * The volume for the audio track elements.
    */
   g_object_class_install_property (object_class, PROP_VOLUME,
       g_param_spec_double ("volume", "Audio Volume",
index 46e6111..b758165 100644 (file)
@@ -188,7 +188,7 @@ ges_text_overlay_create_element (GESTrackElement * object)
  * @text: the text to render. an internal copy of this text will be
  * made.
  *
- * Sets the text this track object will render.
+ * Sets the text this track element will render.
  *
  */
 void
@@ -209,7 +209,7 @@ ges_text_overlay_set_text (GESTextOverlay * self, const gchar * text)
  * @self: the #GESTextOverlay
  * @font_desc: the pango font description
  *
- * Sets the pango font description of the text this track object
+ * Sets the pango font description of the text this track element
  * will render.
  *
  */
index 40522f6..1c3ff38 100644 (file)
@@ -462,7 +462,7 @@ ges_timeline_layer_is_empty (GESTimelineLayer * layer)
  *
  * Calling this method will construct and properly set all the media related
  * elements on @object. If you need to know when those objects (actually #GESTrackElement)
- * are constructed, you should connect to the object::track-object-added signal which
+ * are constructed, you should connect to the object::track-element-added signal which
  * is emited right after those elements are ready to be used.
  *
  * Returns: TRUE if the object was properly added to the layer, or FALSE
index 151e760..bfdc00e 100644 (file)
@@ -107,7 +107,7 @@ struct _MoveContext
   guint64 max_trim_pos;
 
   /* fields to force/avoid new context */
-  /* Set to %TRUE when the track is doing updates of track objects
+  /* Set to %TRUE when the track is doing updates of track element
    * properties so we don't end up always needing new move context */
   gboolean ignore_needs_ctx;
   gboolean needs_move_ctx;
@@ -448,7 +448,7 @@ ges_timeline_class_init (GESTimelineClass * klass)
       GES_TYPE_TIMELINE_LAYER);
 
   /**
-   * GESTimeline::track-objects-snapping:
+   * GESTimeline::track-elements-snapping:
    * @timeline: the #GESTimeline
    * @obj1: the first #GESTrackElement that was snapping.
    * @obj2: the second #GESTrackElement that was snapping.
@@ -484,8 +484,8 @@ ges_timeline_class_init (GESTimelineClass * klass)
   /**
    * GESTimeline::select-tracks-for-object:
    * @timeline: the #GESTimeline
-   * @clip: The #GESClip on which @track-object will land
-   * @track-object: The #GESTrackElement for which to choose the tracks it should land into
+   * @clip: The #GESClip on which @track-element will land
+   * @track-element: The #GESTrackElement for which to choose the tracks it should land into
    *
    * Returns: (transfer full) (element-type GESTrack): a #GPtrArray of #GESTrack-s where that object should be added
    *
@@ -1734,13 +1734,13 @@ add_object_to_track (GESClip * object, GESTrackElement * track_element,
 {
   if (!ges_clip_add_track_element (object, track_element)) {
     GST_WARNING_OBJECT (object,
-        "Failed to add track object to timeline object");
+        "Failed to add track element to timeline object");
     gst_object_unref (track_element);
     return;
   }
 
   if (!ges_track_add_object (track, track_element)) {
-    GST_WARNING_OBJECT (object, "Failed to add track object to track");
+    GST_WARNING_OBJECT (object, "Failed to add track element to track");
     ges_clip_release_track_element (object, track_element);
     gst_object_unref (track_element);
     return;
@@ -1895,7 +1895,7 @@ layer_object_removed_cb (GESTimelineLayer * layer, GESClip * object,
 
   GST_DEBUG ("Clip %p removed from layer %p", object, layer);
 
-  /* Go over the object's track objects and figure out which one belongs to
+  /* Go over the object's track element and figure out which one belongs to
    * the list of tracks we control */
 
   trackelements = ges_clip_get_track_elements (object);
@@ -2373,7 +2373,7 @@ ges_timeline_remove_layer (GESTimeline * timeline, GESTimelineLayer * layer)
  * Returns: TRUE if the track was properly added, else FALSE.
  */
 
-/* FIXME: create track objects for timeline objects which have already been
+/* FIXME: create track elements for timeline objects which have already been
  * added to existing layers.
  */
 
@@ -2420,12 +2420,12 @@ ges_timeline_add_track (GESTimeline * timeline, GESTrack * track)
   g_signal_emit (timeline, ges_timeline_signals[TRACK_ADDED], 0, track);
 
   /* ensure that each existing timeline object has the opportunity to create a
-   * track object for this track*/
+   * track element for this track*/
 
   /* We connect to the object for the timeline editing mode management */
-  g_signal_connect (G_OBJECT (track), "track-object-added",
+  g_signal_connect (G_OBJECT (track), "track-element-added",
       G_CALLBACK (track_element_added_cb), timeline);
-  g_signal_connect (G_OBJECT (track), "track-object-removed",
+  g_signal_connect (G_OBJECT (track), "track-element-removed",
       G_CALLBACK (track_element_removed_cb), timeline);
 
   for (tmp = timeline->layers; tmp; tmp = tmp->next) {
@@ -2456,9 +2456,9 @@ ges_timeline_add_track (GESTimeline * timeline, GESTrack * track)
  * Returns: TRUE if the @track was properly removed, else FALSE.
  */
 
-/* FIXME: release any track objects associated with this layer. currenly this
+/* FIXME: release any track elements associated with this layer. currenly this
  * will not happen if you remove the track before removing *all*
- * clips which have a track object in this track.
+ * clips which have a track element in this track.
  */
 
 gboolean
index 9449c6d..3092d0e 100644 (file)
@@ -190,7 +190,7 @@ ges_title_source_create_element (GESTrackElement * object)
  * @text: the text to render. an internal copy of this text will be
  * made.
  * 
- * Sets the text this track object will render.
+ * Sets the text this track element will render.
  */
 
 void
index 33ebf35..4b70084 100644 (file)
@@ -793,10 +793,10 @@ ges_track_element_set_clip (GESTrackElement * object, GESClip * clipect)
  * ges_track_element_get_clip:
  * @object: a #GESTrackElement
  *
- * Get the #GESClip which is controlling this track object
+ * Get the #GESClip which is controlling this track element
  *
  * Returns: (transfer none): the #GESClip which is controlling
- * this track object
+ * this track element
  */
 GESClip *
 ges_track_element_get_clip (GESTrackElement * object)
@@ -826,9 +826,9 @@ ges_track_element_get_gnlobject (GESTrackElement * object)
  * ges_track_element_get_element:
  * @object: a #GESTrackElement
  *
- * Get the #GstElement this track object is controlling within GNonLin.
+ * Get the #GstElement this track element is controlling within GNonLin.
  *
- * Returns: (transfer none): the #GstElement this track object is controlling
+ * Returns: (transfer none): the #GstElement this track element is controlling
  * within GNonLin.
  */
 GstElement *
index 3d87c4e..8da47f4 100644 (file)
@@ -516,30 +516,30 @@ ges_track_class_init (GESTrackClass * klass)
       properties[ARG_TYPE]);
 
   /**
-   * GESTrack::track-object-added:
+   * GESTrack::track-element-added:
    * @object: the #GESTrack
    * @effect: the #GESTrackElement that was added.
    *
-   * Will be emitted after a track object was added to the track.
+   * Will be emitted after a track element was added to the track.
    *
    * Since: 0.10.2
    */
   ges_track_signals[TRACK_ELEMENT_ADDED] =
-      g_signal_new ("track-object-added", G_TYPE_FROM_CLASS (klass),
+      g_signal_new ("track-element-added", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_FIRST, 0, NULL, NULL, g_cclosure_marshal_generic,
       G_TYPE_NONE, 1, GES_TYPE_TRACK_ELEMENT);
 
   /**
-   * GESTrack::track-object-removed:
+   * GESTrack::track-element-removed:
    * @object: the #GESTrack
    * @effect: the #GESTrackElement that was removed.
    *
-   * Will be emitted after a track object was removed from the track.
+   * Will be emitted after a track element was removed from the track.
    *
    * Since: 0.10.2
    */
   ges_track_signals[TRACK_ELEMENT_REMOVED] =
-      g_signal_new ("track-object-removed", G_TYPE_FROM_CLASS (klass),
+      g_signal_new ("track-element-removed", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_FIRST, 0, NULL, NULL, g_cclosure_marshal_generic,
       G_TYPE_NONE, 1, GES_TYPE_TRACK_ELEMENT);
 }
index 145b7c7..4162288 100644 (file)
@@ -411,7 +411,7 @@ ges_uri_clip_create_track_element (GESClip * obj, GESTrackType type)
     /* FIXME : Implement properly ! */
     res = (GESTrackElement *) ges_track_filesource_new (priv->uri);
 
-    /* If mute and track is audio, deactivate the track object */
+    /* If mute and track is audio, deactivate the track element */
     if (type == GES_TRACK_TYPE_AUDIO && priv->mute)
       ges_track_element_set_active (res, FALSE);
   }
index cb09440..1aad0d3 100644 (file)
--- a/ges/ges.c
+++ b/ges/ges.c
@@ -81,7 +81,7 @@ ges_init (void)
   GES_TYPE_PITIVI_FORMATTER;
   GES_TYPE_XML_FORMATTER;
 
-  /* Register track objects */
+  /* Register track elements */
   GES_TYPE_EFFECT;
 
   /* Register interfaces */
index ef1fa28..c39adf4 100644 (file)
@@ -541,7 +541,7 @@ GST_START_TEST (test_ges_timeline_remove_track)
    * 1 added by ourselves above (g_object_ref (t1)) */
   ASSERT_OBJECT_REFCOUNT (t3, "t3", 4);
 
-  /* remove the track and check that the track objects have been released */
+  /* remove the track and check that the track elements have been released */
   fail_unless (ges_timeline_remove_track (timeline, track));
 
   ASSERT_OBJECT_REFCOUNT (t1, "trackelement", 2);
index 84f6a19..f2dbb2e 100644 (file)
@@ -44,7 +44,7 @@ GST_START_TEST (test_transition_basic)
   fail_unless (tr2 != 0);
   fail_unless (tr2->vtype == 1);
 
/* Make sure track object is created and vtype is set */
   trackelement = ges_clip_create_track_element (GES_CLIP (tr2), track->type);
   ges_clip_add_track_element (GES_CLIP (tr2), trackelement);
 
@@ -132,18 +132,18 @@ GST_START_TEST (test_transition_properties)
   assert_equals_int (ges_video_transition_get_transition_type
       (GES_VIDEO_TRANSITION (trackelement)), 1);
 
-  GST_DEBUG ("Releasing track object");
+  GST_DEBUG ("Releasing track element");
   ges_clip_release_track_element (object, trackelement);
 
   g_object_set (object, "vtype", 1, NULL);
 
-  GST_DEBUG ("creating track object");
+  GST_DEBUG ("creating track element");
   trackelement = ges_clip_create_track_element (object, track->type);
   ges_clip_add_track_element (object, trackelement);
   fail_unless (trackelement != NULL);
   fail_unless (ges_track_element_set_track (trackelement, track));
 
/* The new track object should have taken the previously set transition
    * type (in this case 1) */
   GST_DEBUG ("Setting to vtype:1");
   assert_equals_int (ges_video_transition_get_transition_type
index dee5b1a..9ac452f 100644 (file)
@@ -195,17 +195,17 @@ GST_START_TEST (test_filesource_images)
   a = ges_track_audio_raw_new ();
   v = ges_track_video_raw_new ();
 
/* set the is_image property to true then create a video track object. */
   g_object_set (G_OBJECT (uriclip), "is-image", TRUE, NULL);
 
/* the returned track object should be an image source */
   trobj = ges_clip_create_track_element (clip, v->type);
   ges_clip_add_track_element (clip, trobj);
   fail_unless (GES_IS_IMAGE_SOURCE (trobj));
 
   /* The track holds a reference to the object
    * and the timelinobject holds a reference to the object */
-  ASSERT_OBJECT_REFCOUNT (trobj, "Video Track Object", 2);
+  ASSERT_OBJECT_REFCOUNT (trobj, "Video Track Element", 2);
 
   ges_track_remove_object (v, trobj);
   ges_clip_release_track_element (clip, trobj);
index 257c7e1..709e131 100644 (file)
@@ -1486,7 +1486,7 @@ quit_item_activate_cb (GtkMenuItem * item, App * app)
 void
 delete_activate_cb (GtkAction * item, App * app)
 {
-  /* get a gslist of selected track objects */
+  /* get a gslist of selected track elements */
   GList *objects = NULL;
 
   objects = app_get_selected_objects (app);
@@ -44,7 +44,7 @@ GST_START_TEST (test_transition_basic)
   fail_unless (tr2->vtype == 1);
 
-  /* Make sure track object is created and vtype is set */
+  /* Make sure track element is created and vtype is set */
   trackelement = ges_clip_create_track_element (GES_CLIP (tr2), track->type);
   ges_clip_add_track_element (GES_CLIP (tr2), trackelement);
@@ -132,18 +132,18 @@ GST_START_TEST (test_transition_properties)
   fail_unless (ges_track_element_set_track (trackelement, track));
 
-  /* The new track object should have taken the previously set transition
+  /* The new track element should have taken the previously set transition
    * type (in this case 1) */
   GST_DEBUG ("Setting to vtype:1");
@@ -195,17 +195,17 @@ GST_START_TEST (test_filesource_images)
   v = ges_track_video_raw_new ();
 
-  /* set the is_image property to true then create a video track object. */
+  /* set the is_image property to true then create a video track element. */
   g_object_set (G_OBJECT (uriclip), "is-image", TRUE, NULL);
 
@@ -195,17 +195,17 @@ GST_START_TEST (test_filesource_images)
   g_object_set (G_OBJECT (uriclip), "is-image", TRUE, NULL);
 
-  /* the returned track object should be an image source */
+  /* the returned track element should be an image source */
   trobj = ges_clip_create_track_element (clip, v->type);
   ges_clip_add_track_element (clip, trobj);